.. eossr documentation master file, created by
   sphinx-quickstart on Wed Sep  8 16:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to eOSSR's documentation!
=================================

.. toctree::
   :maxdepth: 4
   :glob:

   README
   docstring
   metadata
   notebooks/ossr_statistics.ipynb
   examples
   gitlab_to_zenodo
   snippets
   resources


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
